[sane-devel] genesys:libusb:.... changes while scanning (sane)

2014-01-29 Thread n d
Hi,
So I created simple udev rules:
ATTR{product}==CanoScan, KERNEL==2-5.1, SYMLINK+=bus/usb/002/SCANNER1
ATTR{product}==CanoScan, KERNEL==2-5.2, SYMLINK+=bus/usb/002/SCANNER2
ATTR{product}==CanoScan, KERNEL==2-5.3, SYMLINK+=bus/usb/002/SCANNER3
ATTR{product}==CanoScan, KERNEL==2-5.4, SYMLINK+=bus/usb/002/SCANNER4

now scanimage -L give the next result:
device `genesys:libusb:002:013' is a Canon LiDE 700F flatbed scanner
device `genesys:libusb:002:014' is a Canon LiDE 700F flatbed scanner
device `genesys:libusb:002:015' is a Canon LiDE 700F flatbed scanner
device `genesys:libusb:002:016' is a Canon LiDE 700F flatbed scanner
device `genesys:libusb:002:SCANNER1' is a Canon LiDE 700F flatbed scanner
device `genesys:libusb:002:SCANNER4' is a Canon LiDE 700F flatbed scanner
device `genesys:libusb:002:SCANNER2' is a Canon LiDE 700F flatbed scanner
device `genesys:libusb:002:SCANNER3' is a Canon LiDE 700F flatbed scanner

when scanning for the first time (lets say calling to
 `genesys:libusb:002:SCANNER1' it works)
but when trying to call to the rest of the scanners i get error messages
like

scanimage: open of device genesys:libusb:002:SCANNER2 failed: Invalid
argument
or
scanimage: sane_start: Invalid argument

that happens *manually* too.

any idea?

tnx alot.



On Mon, Jan 27, 2014 at 3:07 PM, Richard Ryniker ryniker at alum.mit.eduwrote:

 Is there any way to give each scanners a persistent (and informative)
 name?

 Udev is the general mechanism for this.
 https://en.wikipedia.org/wiki/Udev gives an overview.

 does anyone have some idea why the usb numbering changes while running
 the script? (tried to run the commands manually one by one, no change in
 scanners name for this case)

 Probably a timing issue.  Your script performs some USB activity, then
 again before the device has completely finished.  The second operation
 (busy device) confuses the software, which resets to put the device into
 a known state (this causes the new device number).  When you execute
 commands from your script manually, the extra time allows completion of
 device activity and no reset occurs.

-- next part --
An HTML attachment was scrubbed...
URL: 
http://lists.alioth.debian.org/pipermail/sane-devel/attachments/20140129/ff54c55e/attachment.html


[sane-devel] UMAX UC630 patches

2014-01-29 Thread m. allan noah
We got your patches. I usually wait around for awhile to see if a
backend author steps forward to shepherd the patches. Since that does
not appear to be happening here, I will commit them myself later
today.

Thanks for your patience.

allan

On Mon, Jan 27, 2014 at 5:36 PM, Ondrej Zary linux at rainbow-software.org 
wrote:
 Hello,
 I've sent 4 patches for UMAX UC630 3 weeks ago but received no reply. Are they
 going to be committed or is there anything I should fix?

 Patch list:
 umax: fix window descriptor block length for UC630
 umax: disable gamma download for UC630
 umax: disable negative for UC630
 umax: UC630 supports 300 x 600 dpi

 --
 Ondrej Zary

 --
 sane-devel mailing list: sane-devel at lists.alioth.debian.org
 http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/sane-devel
 Unsubscribe: Send mail with subject unsubscribe your_password
  to sane-devel-request at lists.alioth.debian.org



-- 
The truth is an offense, but not a sin



[sane-devel] Support AV220D2+ scanner

2014-01-29 Thread Cecilia Biolatti
Hi, sorry for my poor english.

I'm appending  the AV220D2 + scanner to backend as follows:

 { NULL, NULL,

  0x0638, 0x1A31,

  Avision, AV220D2+,

 AV_INT_BUTTON | AV_CANCEL_BUTTON ,AV_USE_GRAY_FILTER|AV_FIRMWARE},


But in lineart mode, the resulting image is all black. If I set 512 as size
for the gamma table (gamma_table_raw_size = gamma_table_size = 512, in
 SANE_Status send_gamma (Avision_Scanner * s)).
In addition, there is a problem in obtaining SANE_STATUS_EOF in the
reader_process method. In the following cases:
1 - read rear line: only emit a eof status. The following status  returned
is SANE_STATUS_OK, with data of the following page (see image1).
2 - read front lines: In this case emit a eof status  per side of the page.

In last read, when the scanner returns an eof status, a striped band is
obtained at the bottom  if you scan in lineart mode(see Image2), or gray
stripe , if set  color or gray mode.

The scanner has the following characteristics:
- [avision] attach: [91] ASIC 8
- Bits per channel: 1, 8, 16

Environment:
Sane-backends: 1.0.25
OS : Open Suse 12.1

The images were obtained using xsane

I await your response.
Best Regards!
-- next part --
An HTML attachment was scrubbed...
URL: 
http://lists.alioth.debian.org/pipermail/sane-devel/attachments/20140129/ef1ee42d/attachment-0001.html
-- next part --
A non-text attachment was scrubbed...
Name: Image1.tiff
Type: image/tiff
Size: 71570 bytes
Desc: not available
URL: 
http://lists.alioth.debian.org/pipermail/sane-devel/attachments/20140129/ef1ee42d/attachment-0001.tiff


[sane-devel] Imageclass d530 scanner

2014-01-29 Thread Rolf Bensch
Hi Gilad,

I prepared a patch for your scanner some weeks ago. But unfortunately
receiving USB data from the scanner stuck somewhere in the OS.
Fortunately you have a different OS. Pleae try the attached patch.

First you must install SANE from git as described here:
http://www.sane-project.org/README.linux.

Then patch the file backend/pixma_imageclass.c with attached
pixma_imageclass.c.patch4_all:
$ patch pixma_imageclass.c pixma_imageclass.c.patch4_all

and copy attached d530.rules to /etc/udev/rules.d/

After everything has been compiled and installed, please check if you
can access your scanner as described in README.linux.

If your scanner has problems, please enable debug output:
$ export SANE_DEBUG_PIXMA=11

and create a log file with (scan area of 5mm x 5mm in color @ 75dpi ):
$ scanimage -x 5 -y 5 2 pixma.log  pixma.pnm

Many thanks for your help.

Cheers,
Rolf


Am 24.01.2014 16:39, schrieb Giladsom:
 Hello there,
 I just bought an Imageclass d530 printer.
 I was able to activate the printer, but I cannot find any way to activate
 the scanner. The computer just doesn't recognize it.
 I am using UBUNTU 13.04.

 Can you please help me?

 Gilad




-- next part --
--- ./pixma_imageclass.c2014-01-29 16:38:27.0 +0100
+++ ../sane-backends/backend/pixma_imageclass.c 2014-01-29 16:41:42.0 
+0100
@@ -94,6 +94,7 @@
 #define MF6680_PID 0x26fa
 #define MF8030_PID 0x2707
 #define IR1133_PID 0x2742
+#define D530_PID   0x2775
 
 
 enum iclass_state_t
@@ -412,8 +413,9 @@
 return error;
   if (s-param-source == PIXMA_SOURCE_ADF  !has_paper (s))
 return PIXMA_ENO_PAPER;
-  /* activate only seen for generation 1 scanners */
-  if (mf-generation == 1)
+  /* activate only seen for generation 1 scanners
+   * but not for D530 */
+  if (mf-generation == 1  s-cfg-pid != D530_PID)
 {
   if (error = 0)
 error = activate (s, 0);
@@ -470,8 +472,9 @@
   mf-cb.cmd_header_len = 10;
   mf-cb.cmd_len_field_ofs = 7;
 
-  /* set generation = 2 for new multifunctionals */
-  mf-generation = (s-cfg-pid = MF8030_PID) ? 2 : 1;
+  /* set generation = 2 for new multifunctionals
+   * except D530 is a generation 1 scanner */
+  mf-generation = (s-cfg-pid = MF8030_PID  s-cfg-pid != D530_PID) ? 2 
: 1;
   PDBG (pixma_dbg (3, *iclass_open* This is a generation %d scanner.  
*\n, mf-generation));
 
   PDBG (pixma_dbg (3, Trying to clear the interrupt buffer...\n));
@@ -563,6 +566,8 @@
   if (error = 0)
 error = send_scan_param (s);
   if (error = 0)
+error = query_status (s);
+  if (error = 0)
 error = request_image_block (s, 0, ignore, ignore2, ignore, ignore2);
   if (error  0)
 {
@@ -785,5 +790,6 @@
   DEV (Canon i-SENSYS MF5880dn, MF5880, MF5880_PID, 600, 640, 877, 
PIXMA_CAP_ADFDUP),
   DEV (Canon i-SENSYS MF6680dn, MF6680, MF6680_PID, 600, 640, 877, 
PIXMA_CAP_ADFDUP),
   DEV (Canon imageRUNNER 1133, iR1133, IR1133_PID, 600, 637, 877, 
PIXMA_CAP_ADFDUP),
+  DEV (Canon imageCLASS D530, D530, D530_PID, 600, 640, 877, 0),
   DEV (NULL, NULL, 0, 0, 0, 0, 0)
 };
-- next part --
# Canon imageCLASS D530
ATTRS{idVendor}==04a9, ATTRS{idProduct}==2775, MODE=0664, 
GROUP=scanner, ENV{libsane_matched}=yes


[sane-devel] genesys:libusb:.... changes while scanning (sane)

2014-01-29 Thread Richard Ryniker
Summary: you have four USB scanners; plug them in, and SANE can access
any one of them successfully, but then cannot access any of the three
other scanners.

If you unplug one scanner, then plug it in again, can SANE then use that
scanner?  This action should re-create the device's data structures and
thereby clear any status left by earlier activity.  If the re-plugged
scanner works, this suggests SANE changes the state of the scanners it
did not use in some way that interferes with later use.



[sane-devel] genesys:libusb:.... changes while scanning (sane)

2014-01-29 Thread Stef
On 29/01/2014 12:26, n d wrote:
 Hi,
 So I created simple udev rules:
 ATTR{product}==CanoScan, KERNEL==2-5.1, 
 SYMLINK+=bus/usb/002/SCANNER1
 ATTR{product}==CanoScan, KERNEL==2-5.2, 
 SYMLINK+=bus/usb/002/SCANNER2
 ATTR{product}==CanoScan, KERNEL==2-5.3, 
 SYMLINK+=bus/usb/002/SCANNER3
 ATTR{product}==CanoScan, KERNEL==2-5.4, 
 SYMLINK+=bus/usb/002/SCANNER4

 now scanimage -L give the next result:
 device `genesys:libusb:002:013' is a Canon LiDE 700F flatbed scanner
 device `genesys:libusb:002:014' is a Canon LiDE 700F flatbed scanner
 device `genesys:libusb:002:015' is a Canon LiDE 700F flatbed scanner
 device `genesys:libusb:002:016' is a Canon LiDE 700F flatbed scanner
 device `genesys:libusb:002:SCANNER1' is a Canon LiDE 700F flatbed scanner
 device `genesys:libusb:002:SCANNER4' is a Canon LiDE 700F flatbed scanner
 device `genesys:libusb:002:SCANNER2' is a Canon LiDE 700F flatbed scanner
 device `genesys:libusb:002:SCANNER3' is a Canon LiDE 700F flatbed scanner

 when scanning for the first time (lets say calling to 
  `genesys:libusb:002:SCANNER1' it works)
 but when trying to call to the rest of the scanners i get error 
 messages like

 scanimage: open of device genesys:libusb:002:SCANNER2 failed: Invalid 
 argument
 or
 scanimage: sane_start: Invalid argument

 that happens _manually_ too.

 any idea?

 tnx alot.



 Hello,

 can you provide a debug log ? Run scanimage with debug trace 
enabled by:

export SANE_DEBUG_GENESYS=255
export SANE_DEBUG_GENESYS_LOW=255
export SANE_DEBUG_GENESYS_GL847=255

and redirect stderr to a log file, for instance a preview would be like:

export SANE_DEBUG_GENESYS=255
export SANE_DEBUG_GENESYS_LOW=255
export SANE_DEBUG_GENESYS_GL847=255
scanimage -d genesys:libusb:002:SCANNER2 --mode Color preview.pnm 
2debug.log

 Then send us the debug log (compressed to keep the mail below the 
max size allowed by the mailing list). In cas there is nothin obvious in 
log, you may add

export SANE_DEBUG_SANEI_USB=255

to get sanei_usb functions log.

Regards,
 Stef


-- next part --
An HTML attachment was scrubbed...
URL: 
http://lists.alioth.debian.org/pipermail/sane-devel/attachments/20140129/bbc5923f/attachment.html


[sane-devel] gscan2pdf v1.2.3 released

2014-01-29 Thread Jeffrey Ratcliffe
gscan2pdf - A GUI to produce a multipage PDF or DjVu from a scan.

http://gscan2pdf.sourceforge.net/

Only two clicks are required to scan several pages and then save all or
a selection as a PDF or DjVu file, including metadata if required.

gscan2pdf can control regular or sheet-fed (ADF) scanners with SANE via
libsane-perl, scanimage or scanadf, and can scan multiple pages at
once. It presents a thumbnail view of scanned pages, and permits simple
operations such as cropping, rotating and deleting pages.

OCR can be used to recognise text in the scans, and the output
embedded in the PDF or DjVu.

PDF conversion is done by PDF::API2.

The resulting document may be saved as a PDF, DjVu, multipage TIFF file,
or single page image file.


Changelog for 1.2.3:

* Deal with crashed sessions with no session file
* Fixed bug setting TMPDIR in preferences
* Added menu item 'Open crashed session'
* Don't process empty lists of pages
  Closes bug #165 all or selected? a surprise that can bite like snake


Changelog for 1.2.2:

* Fixed paper editor widget
* Fixed position of paper size widget
* Hide geometry widgets at startup if paper selected


Changelog for 1.2.1:

* Fixed opening saved sessions
* Fixed storing resolution of scanned images
  Closes Debian bug #734854 (gscan2pdf wrong resolution)


-- next part --
A non-text attachment was scrubbed...
Name: signature.asc
Type: application/pgp-signature
Size: 198 bytes
Desc: OpenPGP digital signature
URL: 
http://lists.alioth.debian.org/pipermail/sane-devel/attachments/20140129/77089520/attachment.sig